@@ -1,8 +1,8 @@
 /*
  *   Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007
  *   NOVELL (All rights reserved)
- *   Copyright (c) 2010
- *   Canonical, Ltd.
+ *   Copyright (c) 2010 - 2012
+ *   Canonical Ltd.
  *
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of version 2 of the GNU General Public
@@ -21,8 +21,6 @@
 #define PARSER_INCLUDE_H
 
 extern int preprocess_only;
-extern int current_lineno;
-extern char *current_filename;
 
 extern int add_search_dir(char *dir);
 extern void init_base_dir(void);
